<?php

namespace Drupal\rating\Utility;

/**
 * Contains utility methods for the Rating.
 */
class Utility {

  /**
   * Get the current rating value for a particular node.
   *
   * @param int $node
   *   The node id to get the rating value for.
   *
   * @return int
   *   The rating value for the currently selected node.
   */
  public static function getRating($node) {
    $rating = 0;
    $connection = \Drupal::database();
    $query = $connection->select('rating_data', 'r')
      ->fields('r', ['rating'])
      ->condition('nid', $node, '=');
    $results = $query->execute()->fetchCol();
    $count = count($results);
    if ($count > 0) {
      $query = "SELECT ROUND(AVG(rating), 1) FROM {rating_data} WHERE nid=" . $node;
      $rating = $connection->query($query)->fetchField();
    }
    return $rating;
  }

  /**
   * Get the current star rating value for a particular node.
   *
   * @param int $user
   *   The id of the user that is creating/updating this rating.
   * @param int $node
   *   The current node id that the selected user is
   *   creating/updating a rating for.
   *
   * @return int
   *   The rating value for the currently selected node.
   */
  public static function getStarRating($user, $node) {
    $rating = 0;
    $connection = \Drupal::database();
    $query = $connection->select('rating_data', 'r')
      ->fields('r', ['rating'])
      ->condition('nid', $node, '=')
      ->condition('uid', $user, '=');
    $results = $query->execute()->fetchCol();
    $count = count($results);
    if ($count > 0) {
      $query = $connection->select('rating_data', 'r')
        ->fields('r', ['rating'])
        ->condition('nid', $node, '=')
        ->condition('uid', $user, '=');
      $rating = $query->execute()->fetchField();
    }
    return $rating;
  }

  /**
   * Create/update the rating value for the node, generated by the user.
   *
   * @param int $user
   *   The id of the user that is creating/updating this rating.
   * @param int $node
   *   The current node id that the selected user is
   *   creating/updating a rating for.
   * @param int $rating
   *   The rating value that the user selected.
   */
  public static function setRating($user, $node, $rating) {
    $current_time = \Drupal::time()->getCurrentTime();
    $connection = \Drupal::database();
    $query = $connection->select('rating_data', 'r')
      ->fields('r', ['rating'])
      ->condition('uid', $user, '=')
      ->condition('nid', $node, '=');
    $results = $query->execute()->fetchCol();
    $count = count($results);
    if ($count > 0) {
      $results = $connection->update('rating_data')
        ->fields([
          'uid' => $user,
          'nid' => $node,
          'rating' => $rating,
          'changed' => $current_time,
        ])->condition('nid', $node, '=')->condition('uid', $user, '=')->execute();
    }
    else {
      $results = $connection->insert('rating_data')
        ->fields([
          'uid' => $user,
          'nid' => $node,
          'rating' => $rating,
          'changed' => $current_time,
          'created' => $current_time,
        ])->execute();
    }
  }

}
